src/hg/utils/automation/makePushQSql.pl 1.25

1.25 2009/06/08 18:37:16 hiram
hgofbeta is now hgsqlbeta, and generalize the ssh command
Index: src/hg/utils/automation/makePushQSql.pl
===================================================================
RCS file: /projects/compbio/cvsroot/kent/src/hg/utils/automation/makePushQSql.pl,v
retrieving revision 1.24
retrieving revision 1.25
diff -b -B -U 4 -r1.24 -r1.25
--- src/hg/utils/automation/makePushQSql.pl	8 May 2009 23:05:22 -0000	1.24
+++ src/hg/utils/automation/makePushQSql.pl	8 Jun 2009 18:37:16 -0000	1.25
@@ -71,9 +71,9 @@
 
 sub isChrom($$) {
   # Return true if $str is in chromInfo.chrom.
   my ($str, $localDb) = @_;
-  my $localSql = "ssh -x $dbHost hgsql -N $localDb";
+  my $localSql = "$HgAutomate::runSSH $dbHost hgsql -N $localDb";
   my %localHash = ();
   my $hashRef = \%localHash;
   if (exists($chromInfoDb{$localDb})) {
     $hashRef = $chromInfoDb{$localDb};
@@ -93,9 +93,9 @@
   # Well, almost all -- ignore per-user trackDb.ra-derived tables, the
   # cron-generated tableDescriptions, and tables that we never push.
   # And collapse split tables.
   my ($localDb) = @_;
-  my $localSql = "ssh -x $dbHost hgsql -N $localDb";
+  my $localSql = "$HgAutomate::runSSH $dbHost hgsql -N $localDb";
   my %tables = ();
   foreach my $t (`echo show tables | $localSql`) {
     chomp $t;
     next if ($t =~ /^(trackDb|hgFindSpec)_\w+/);
@@ -581,9 +581,9 @@
   # to the new $db push queue created above.
   my $date = `date +%Y-%m-%d`;
   my $size = 0;
   chomp $date;
-  my $qapushqSql = 'ssh -x hgwbeta hgsql -h hgofbeta -N qapushq';
+  my $qapushqSql = "$HgAutomate::runSSH hgwbeta hgsql -h hgsqlbeta -N qapushq";
   my $rankQuery = 'select rank from pushQ order by rank desc limit 1';
   my $rank = `echo $rankQuery | $qapushqSql`;
   $rank += 1;
   my (undef, undef, $assemblyLabel) =
@@ -648,14 +648,14 @@
  *** 5. This script currently does not recognize composite tracks.  If $db
         has any composite tracks, you should manually merge the separate
         per-table entries into one entry.
  *** 6. Make sure that qapushq does not already have a table named $db:
-          ssh hgwbeta hgsql -h hgofbeta qapushq -NBe "'desc $db;'"
+          ssh hgwbeta hgsql -h hgsqlbeta qapushq -NBe "'desc $db;'"
         You *should* see this error:
           ERROR 1146 at line 1: Table 'qapushq.$db' doesn't exist
         If it already has that table, talk to QA and figure out whether
         it can be dropped or fixed up (by sql or the Push Queue web app).
  *** When everything is complete and correct, use hgsql -h hgofbeta to
      execute the sql file.  Then use the Push Queue web app to check the
      contents of all entries.
  *** If you haven't already, please add $db to makeDb/schema/all.joiner !
      It should be in both \$gbd and \$chainDest.
@@ -683,9 +683,9 @@
 
 &usage(1) if (scalar(@ARGV) != 1);
 ($db) = @ARGV;
 
-$sql = "ssh -x $dbHost hgsql -N $db";
+$sql = "$HgAutomate::runSSH $dbHost hgsql -N $db";
 
 &makePushQSql();
 
@@ -648,14 +648,14 @@
         If it already has that table, talk to QA and figure out whether
         it can be dropped or fixed up (by sql or the Push Queue web app).
- *** When everything is complete and correct, use hgsql -h hgofbeta to
+ *** When everything is complete and correct, use hgsql -h hgsqlbeta to
      execute the sql file.  Then use the Push Queue web app to check the
      contents of all entries.
 &adviseDeveloper();